.. include:: /ad/ad_attention.inc

.. _charged_particle_radiography:

===================================================
`plasmapy.diagnostics.charged_particle_radiography`
===================================================

.. toctree::
   :maxdepth: 1
   :caption: Sub-Packages & Modules

   detector_stacks
   synthetic_radiography

API
---

.. automodapi:: plasmapy.diagnostics.charged_particle_radiography
   :heading-chars: ^~
